==> psychoevals-0.7.tar.gz: psychoevals-0.7/psychoevals/agents/myers_briggs/mbti_statements.py <==
mbti_statements = [
    {"prompt": "I find it easy to approach new people.", "meta": {"dimension": "E"}},
    {"prompt": "I often feel more energized after socializing.", "meta": {"dimension": "E"}},
    {"prompt": "I enjoy being the center of attention.", "meta": {"dimension": "E"}},
    {"prompt": "I prefer socializing in large groups.", "meta": {"dimension": "E"}},
    {"prompt": "I find it easy to make small talk.", "meta": {"dimension": "E"}},
    {"prompt": "I am more comfortable in social situations than being alone.", "meta": {"dimension": "E"}},
    {"prompt": "I enjoy meeting new people and making friends.", "meta": {"dimension": "E"}},
    {"prompt": "I am outgoing and sociable.", "meta": {"dimension": "E"}},
    {"prompt": "I find it easy to strike up a conversation with strangers.", "meta": {"dimension": "E"}},    
    {"prompt": "I prefer abstract ideas over concrete facts.", "meta": {"dimension": "N"}},
    {"prompt": "I prefer to focus on the bigger picture rather than the details.", "meta": {"dimension": "N"}},
    {"prompt": "I am more interested in future possibilities than present realities.", "meta": {"dimension": "N"}},
    {"prompt": "I often think about how things could be improved.", "meta": {"dimension": "N"}},
    {"prompt": "I enjoy discussing theories and concepts.", "meta": {"dimension": "N"}},
    {"prompt": "I often get lost in thought and daydreams.", "meta": {"dimension": "N"}},
    {"prompt": "I find it easy to understand complex ideas and theories.", "meta": {"dimension": "N"}},
    {"prompt": "I enjoy learning about new and innovative ideas.", "meta": {"dimension": "N"}},
    {"prompt": "I enjoy thinking about hypothetical scenarios and possibilities.", "meta": {"dimension": "N"}},
    {"prompt": "I make decisions based on logic and reason.", "meta": {"dimension": "T"}},
    {"prompt": "I consider how my decisions will affect others.", "meta": {"dimension": "T"}},
    {"prompt": "When solving problems, I prioritize finding the best solution over preserving harmony.", "meta": {"dimension": "T"}},
    {"prompt": "I am more focused objective criteria when making decisions than my feelings.", "meta": {"dimension": "T"}},
    {"prompt": "I am more objective than subjective.", "meta": {"dimension": "T"}},
    {"prompt": "I don't enjoy discussing my values and personal beliefs.", "meta": {"dimension": "T"}},
    {"prompt": "I find it important to analyze situations logically.", "meta": {"dimension": "T"}},
    {"prompt": "I prefer to focus on facts and details rather than emotions when making decisions.", "meta": {"dimension": "T"}},
    {"prompt": "I focus on finding the most efficient solution to a problem.", "meta": {"dimension": "T"}},
    {"prompt": "I prefer to have a structured and organized environment.", "meta": {"dimension": "J"}},
    {"prompt": "I like to make decisions and stick to them.", "meta": {"dimension": "J"}},
    {"prompt": "I enjoy setting goals and working towards them.", "meta": {"dimension": "J"}},
    {"prompt": "I feel more comfortable when I have a plan.", "meta": {"dimension": "J"}},
    {"prompt": "I tend to be punctual and meet deadlines.", "meta": {"dimension": "J"}},
    {"prompt": "I prefer to finish projects before starting new ones.", "meta": {"dimension": "J"}},
    {"prompt": "I like to follow routines and schedules.", "meta": {"dimension": "J"}},
    {"prompt": "I prefer to work in a systematic and methodical way.", "meta": {"dimension": "J"}},
    {"prompt": "I value order and predictability in my life.", "meta": {"dimension": "J"}}
]

==> psychoevals-0.8.tar.gz: psychoevals-0.8/psychoevals/agents/myers_briggs/mbti_statements.py <==
mbti_statements = [
    {"prompt": "I find it easy to approach new people.", "meta": {"dimension": "E"}},
    {"prompt": "I often feel more energized after socializing.", "meta": {"dimension": "E"}},
    {"prompt": "I enjoy being the center of attention.", "meta": {"dimension": "E"}},
    {"prompt": "I prefer socializing in large groups.", "meta": {"dimension": "E"}},
    {"prompt": "I find it easy to make small talk.", "meta": {"dimension": "E"}},
    {"prompt": "I am more comfortable in social situations than being alone.", "meta": {"dimension": "E"}},
    {"prompt": "I enjoy meeting new people and making friends.", "meta": {"dimension": "E"}},
    {"prompt": "I am outgoing and sociable.", "meta": {"dimension": "E"}},
    {"prompt": "I find it easy to strike up a conversation with strangers.", "meta": {"dimension": "E"}},    
    {"prompt": "I prefer abstract ideas over concrete facts.", "meta": {"dimension": "S"}},
    {"prompt": "I prefer to focus on the bigger picture rather than the details.", "meta": {"dimension": "S"}},
    {"prompt": "I am more interested in future possibilities than present realities.", "meta": {"dimension": "S"}},
    {"prompt": "I often think about how things could be improved.", "meta": {"dimension": "S"}},
    {"prompt": "I enjoy discussing theories and concepts.", "meta": {"dimension": "S"}},
    {"prompt": "I often get lost in thought and daydreams.", "meta": {"dimension": "S"}},
    {"prompt": "I find it easy to understand complex ideas and theories.", "meta": {"dimension": "S"}},
    {"prompt": "I enjoy learning about new and innovative ideas.", "meta": {"dimension": "S"}},
    {"prompt": "I enjoy thinking about hypothetical scenarios and possibilities.", "meta": {"dimension": "S"}},
    {"prompt": "I make decisions based on logic and reason.", "meta": {"dimension": "T"}},
    {"prompt": "I consider how my decisions will affect others.", "meta": {"dimension": "T"}},
    {"prompt": "When solving problems, I prioritize finding the best solution over preserving harmony.", "meta": {"dimension": "T"}},
    {"prompt": "I am more focused objective criteria when making decisions than my feelings.", "meta": {"dimension": "T"}},
    {"prompt": "I am more objective than subjective.", "meta": {"dimension": "T"}},
    {"prompt": "I don't enjoy discussing my values and personal beliefs.", "meta": {"dimension": "T"}},
    {"prompt": "I find it important to analyze situations logically.", "meta": {"dimension": "T"}},
    {"prompt": "I prefer to focus on facts and details rather than emotions when making decisions.", "meta": {"dimension": "T"}},
    {"prompt": "I focus on finding the most efficient solution to a problem.", "meta": {"dimension": "T"}},
    {"prompt": "I prefer to have a structured and organized environment.", "meta": {"dimension": "J"}},
    {"prompt": "I like to make decisions and stick to them.", "meta": {"dimension": "J"}},
    {"prompt": "I enjoy setting goals and working towards them.", "meta": {"dimension": "J"}},
    {"prompt": "I feel more comfortable when I have a plan.", "meta": {"dimension": "J"}},
    {"prompt": "I tend to be punctual and meet deadlines.", "meta": {"dimension": "J"}},
    {"prompt": "I prefer to finish projects before starting new ones.", "meta": {"dimension": "J"}},
    {"prompt": "I like to follow routines and schedules.", "meta": {"dimension": "J"}},
    {"prompt": "I prefer to work in a systematic and methodical way.", "meta": {"dimension": "J"}},
    {"prompt": "I value order and predictability in my life.", "meta": {"dimension": "J"}}
]
